var searchData=
[
  ['one_5fvector',['one_vector',['../structviennacl_1_1one__vector.html',1,'viennacl']]],
  ['op_5fabs',['op_abs',['../structviennacl_1_1op__abs.html',1,'viennacl']]],
  ['op_5facos',['op_acos',['../structviennacl_1_1op__acos.html',1,'viennacl']]],
  ['op_5fadd',['op_add',['../structviennacl_1_1op__add.html',1,'viennacl']]],
  ['op_5fapplier',['op_applier',['../structviennacl_1_1linalg_1_1detail_1_1op__applier.html',1,'viennacl::linalg::detail']]],
  ['op_5fargmax',['op_argmax',['../structviennacl_1_1op__argmax.html',1,'viennacl']]],
  ['op_5fargmin',['op_argmin',['../structviennacl_1_1op__argmin.html',1,'viennacl']]],
  ['op_5fasin',['op_asin',['../structviennacl_1_1op__asin.html',1,'viennacl']]],
  ['op_5fassign',['op_assign',['../structop__assign.html',1,'']]],
  ['op_5fassign',['op_assign',['../structviennacl_1_1op__assign.html',1,'viennacl']]],
  ['op_5fatan',['op_atan',['../structviennacl_1_1op__atan.html',1,'viennacl']]],
  ['op_5fatan2',['op_atan2',['../structviennacl_1_1op__atan2.html',1,'viennacl']]],
  ['op_5fceil',['op_ceil',['../structviennacl_1_1op__ceil.html',1,'viennacl']]],
  ['op_5fcolumn',['op_column',['../structviennacl_1_1op__column.html',1,'viennacl']]],
  ['op_5fcos',['op_cos',['../structviennacl_1_1op__cos.html',1,'viennacl']]],
  ['op_5fcosh',['op_cosh',['../structviennacl_1_1op__cosh.html',1,'viennacl']]],
  ['op_5fdiv',['op_div',['../structviennacl_1_1op__div.html',1,'viennacl']]],
  ['op_5felement',['op_element',['../structviennacl_1_1scheduler_1_1op__element.html',1,'viennacl::scheduler']]],
  ['op_5felement_5fbinary',['op_element_binary',['../structviennacl_1_1op__element__binary.html',1,'viennacl']]],
  ['op_5felement_5fcast',['op_element_cast',['../structviennacl_1_1op__element__cast.html',1,'viennacl']]],
  ['op_5felement_5funary',['op_element_unary',['../structviennacl_1_1op__element__unary.html',1,'viennacl']]],
  ['op_5feq',['op_eq',['../structviennacl_1_1op__eq.html',1,'viennacl']]],
  ['op_5fexecutor',['op_executor',['../structviennacl_1_1linalg_1_1detail_1_1op__executor.html',1,'viennacl::linalg::detail']]],
  ['op_5fexp',['op_exp',['../structviennacl_1_1op__exp.html',1,'viennacl']]],
  ['op_5ffabs',['op_fabs',['../structviennacl_1_1op__fabs.html',1,'viennacl']]],
  ['op_5ffdim',['op_fdim',['../structviennacl_1_1op__fdim.html',1,'viennacl']]],
  ['op_5fflip_5fsign',['op_flip_sign',['../structviennacl_1_1op__flip__sign.html',1,'viennacl']]],
  ['op_5ffloor',['op_floor',['../structviennacl_1_1op__floor.html',1,'viennacl']]],
  ['op_5ffmax',['op_fmax',['../structviennacl_1_1op__fmax.html',1,'viennacl']]],
  ['op_5ffmin',['op_fmin',['../structviennacl_1_1op__fmin.html',1,'viennacl']]],
  ['op_5ffmod',['op_fmod',['../structviennacl_1_1op__fmod.html',1,'viennacl']]],
  ['op_5fgeq',['op_geq',['../structviennacl_1_1op__geq.html',1,'viennacl']]],
  ['op_5fgreater',['op_greater',['../structviennacl_1_1op__greater.html',1,'viennacl']]],
  ['op_5finner_5fprod',['op_inner_prod',['../structviennacl_1_1op__inner__prod.html',1,'viennacl']]],
  ['op_5finplace_5fadd',['op_inplace_add',['../structviennacl_1_1op__inplace__add.html',1,'viennacl']]],
  ['op_5finplace_5fsub',['op_inplace_sub',['../structviennacl_1_1op__inplace__sub.html',1,'viennacl']]],
  ['op_5fleq',['op_leq',['../structviennacl_1_1op__leq.html',1,'viennacl']]],
  ['op_5fless',['op_less',['../structviennacl_1_1op__less.html',1,'viennacl']]],
  ['op_5flog',['op_log',['../structviennacl_1_1op__log.html',1,'viennacl']]],
  ['op_5flog10',['op_log10',['../structviennacl_1_1op__log10.html',1,'viennacl']]],
  ['op_5fmat_5fmat_5fprod',['op_mat_mat_prod',['../structviennacl_1_1op__mat__mat__prod.html',1,'viennacl']]],
  ['op_5fmatrix_5fdiag',['op_matrix_diag',['../structviennacl_1_1op__matrix__diag.html',1,'viennacl']]],
  ['op_5fmax',['op_max',['../structviennacl_1_1op__max.html',1,'viennacl']]],
  ['op_5fmin',['op_min',['../structviennacl_1_1op__min.html',1,'viennacl']]],
  ['op_5fminus_5fassign',['op_minus_assign',['../structop__minus__assign.html',1,'']]],
  ['op_5fmult',['op_mult',['../structviennacl_1_1op__mult.html',1,'viennacl']]],
  ['op_5fneq',['op_neq',['../structviennacl_1_1op__neq.html',1,'viennacl']]],
  ['op_5fnorm_5f1',['op_norm_1',['../structviennacl_1_1op__norm__1.html',1,'viennacl']]],
  ['op_5fnorm_5f2',['op_norm_2',['../structviennacl_1_1op__norm__2.html',1,'viennacl']]],
  ['op_5fnorm_5ffrobenius',['op_norm_frobenius',['../structviennacl_1_1op__norm__frobenius.html',1,'viennacl']]],
  ['op_5fnorm_5finf',['op_norm_inf',['../structviennacl_1_1op__norm__inf.html',1,'viennacl']]],
  ['op_5fplus_5fassign',['op_plus_assign',['../structop__plus__assign.html',1,'']]],
  ['op_5fpow',['op_pow',['../structviennacl_1_1op__pow.html',1,'viennacl']]],
  ['op_5fprod',['op_prod',['../structviennacl_1_1op__prod.html',1,'viennacl']]],
  ['op_5freduce_5fcolumns',['op_reduce_columns',['../structviennacl_1_1op__reduce__columns.html',1,'viennacl']]],
  ['op_5freduce_5frows',['op_reduce_rows',['../structviennacl_1_1op__reduce__rows.html',1,'viennacl']]],
  ['op_5freduce_5fvector',['op_reduce_vector',['../structviennacl_1_1op__reduce__vector.html',1,'viennacl']]],
  ['op_5frow',['op_row',['../structviennacl_1_1op__row.html',1,'viennacl']]],
  ['op_5fsin',['op_sin',['../structviennacl_1_1op__sin.html',1,'viennacl']]],
  ['op_5fsinh',['op_sinh',['../structviennacl_1_1op__sinh.html',1,'viennacl']]],
  ['op_5fsqrt',['op_sqrt',['../structviennacl_1_1op__sqrt.html',1,'viennacl']]],
  ['op_5fsub',['op_sub',['../structviennacl_1_1op__sub.html',1,'viennacl']]],
  ['op_5ftan',['op_tan',['../structviennacl_1_1op__tan.html',1,'viennacl']]],
  ['op_5ftanh',['op_tanh',['../structviennacl_1_1op__tanh.html',1,'viennacl']]],
  ['op_5ftrans',['op_trans',['../structviennacl_1_1op__trans.html',1,'viennacl']]],
  ['op_5ftype_5finfo',['op_type_info',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fadd_20_3e',['op_type_info&lt; op_add &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__add_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fassign_20_3e',['op_type_info&lt; op_assign &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__assign_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fcolumn_20_3e',['op_type_info&lt; op_column &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__column_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fdiv_20_3e',['op_type_info&lt; op_div &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__div_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fargmax_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_argmax &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmax_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fargmin_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_argmin &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmin_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fdiv_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_div &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__div_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5feq_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_eq &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__eq_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5ffmax_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_fmax &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmax_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5ffmin_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_fmin &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmin_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fgeq_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_geq &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__geq_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fgreater_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_greater &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__greater_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fleq_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_leq &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__leq_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fless_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_less &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__less_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fneq_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_neq &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__neq_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fpow_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_pow &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__pow_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fbinary_3c_20op_5fprod_20_3e_20_3e',['op_type_info&lt; op_element_binary&lt; op_prod &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__prod_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20char_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; char &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01char_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20double_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; double &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01double_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20float_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; float &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01float_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20int_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; int &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01int_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20long_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; long &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01long_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20short_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; short &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01short_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20unsigned_20char_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; unsigned char &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01char_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20unsigned_20int_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; unsigned int &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01int_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20unsigned_20long_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; unsigned long &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01long_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5fcast_3c_20unsigned_20short_20_3e_20_3e',['op_type_info&lt; op_element_cast&lt; unsigned short &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01short_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fabs_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_abs &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__abs_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5facos_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_acos &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__acos_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fasin_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_asin &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__asin_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fatan_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_atan &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__atan_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fceil_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_ceil &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__ceil_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fcos_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_cos &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cos_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fcosh_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_cosh &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cosh_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fexp_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_exp &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__exp_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5ffabs_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_fabs &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__fabs_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5ffloor_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_floor &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__floor_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5flog_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_log &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5flog10_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_log10 &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log10_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fsin_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_sin &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sin_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fsinh_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_sinh &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sinh_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5fsqrt_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_sqrt &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sqrt_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5ftan_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_tan &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tan_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5felement_5funary_3c_20op_5ftanh_20_3e_20_3e',['op_type_info&lt; op_element_unary&lt; op_tanh &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tanh_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fflip_5fsign_20_3e',['op_type_info&lt; op_flip_sign &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__flip__sign_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5finner_5fprod_20_3e',['op_type_info&lt; op_inner_prod &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inner__prod_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5finplace_5fadd_20_3e',['op_type_info&lt; op_inplace_add &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__add_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5finplace_5fsub_20_3e',['op_type_info&lt; op_inplace_sub &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__sub_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fmat_5fmat_5fprod_20_3e',['op_type_info&lt; op_mat_mat_prod &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mat__mat__prod_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fmatrix_5fdiag_20_3e',['op_type_info&lt; op_matrix_diag &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__matrix__diag_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fmax_20_3e',['op_type_info&lt; op_max &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__max_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fmin_20_3e',['op_type_info&lt; op_min &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__min_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fmult_20_3e',['op_type_info&lt; op_mult &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mult_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fnorm_5f1_20_3e',['op_type_info&lt; op_norm_1 &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__1_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fnorm_5f2_20_3e',['op_type_info&lt; op_norm_2 &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__2_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fnorm_5finf_20_3e',['op_type_info&lt; op_norm_inf &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__inf_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fprod_20_3e',['op_type_info&lt; op_prod &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__prod_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5freduce_5fcolumns_3c_20op_20_3e_20_3e',['op_type_info&lt; op_reduce_columns&lt; OP &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__columns_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5freduce_5frows_3c_20op_20_3e_20_3e',['op_type_info&lt; op_reduce_rows&lt; OP &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__rows_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5freduce_5fvector_3c_20op_20_3e_20_3e',['op_type_info&lt; op_reduce_vector&lt; OP &gt; &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__vector_3_01_o_p_01_4_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5frow_20_3e',['op_type_info&lt; op_row &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__row_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fsub_20_3e',['op_type_info&lt; op_sub &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__sub_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5ftrans_20_3e',['op_type_info&lt; op_trans &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__trans_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5ftype_5finfo_3c_20op_5fvector_5fdiag_20_3e',['op_type_info&lt; op_vector_diag &gt;',['../structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__vector__diag_01_4.html',1,'viennacl::scheduler::result_of']]],
  ['op_5fvector_5fdiag',['op_vector_diag',['../structviennacl_1_1op__vector__diag.html',1,'viennacl']]],
  ['out_5fof_5fhost_5fmemory',['out_of_host_memory',['../classviennacl_1_1ocl_1_1out__of__host__memory.html',1,'viennacl::ocl']]],
  ['out_5fof_5fresources',['out_of_resources',['../classviennacl_1_1ocl_1_1out__of__resources.html',1,'viennacl::ocl']]]
];
